summaryrefslogtreecommitdiffstats
path: root/lib/kross/main/scriptguiclient.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kross/main/scriptguiclient.h')
-rw-r--r--lib/kross/main/scriptguiclient.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/kross/main/scriptguiclient.h b/lib/kross/main/scriptguiclient.h
index af762720..a835d0a2 100644
--- a/lib/kross/main/scriptguiclient.h
+++ b/lib/kross/main/scriptguiclient.h
@@ -58,12 +58,12 @@ namespace Kross { namespace Api {
*
* \param guiclient The KXMLGUIClient this \a ScriptGUIClient
* is a child of.
* \param tqparent The tqparent TQWidget. If defined TQt will handle
* freeing this \a ScriptGUIClient instance else the
* caller has to take care of freeing this instance
* if not needed any longer.
*/
- explicit ScriptGUIClient(KXMLGUIClient* guiclient, TQWidget* tqparent = 0);
+ explicit ScriptGUIClient(KXMLGUIClient* guiclient, TQWidget* parent = 0);
/**
* Destructor.
@@ -58,12 +58,12 @@ namespace Kross { namespace Api {
* \param guiclient The KXMLGUIClient this \a ScriptGUIClient
* is a child of.
- * \param tqparent The tqparent TQWidget. If defined TQt will handle
+ * \param parent The parent TQWidget. If defined TQt will handle
* freeing this \a ScriptGUIClient instance else the
* caller has to take care of freeing this instance